## 开盘啦榜单数据

接口：kpl_list

描述：获取开盘啦涨停、跌停、炸板等榜单数据

限量：单次最大8000条数据，可根据日期循环获取历史数据

积分：5000积分每分钟可以请求200次每天总量1万次，8000积分以上每分钟500次每天总量不限制，具体请参阅积分获取办法 

注：开盘啦是一个优秀的专业打板app，有兴趣的用户可以自行下载安装。本接口仅限用于量化研究，如需商业用途，请自行联系开盘APP官方。

输入参数

| 名称 | 类型 | 必选 | 描述 |
| --- | --- | --- | --- |
| ts_code | str | N | 股票代码 |
| trade_date | str | N | 交易日期 |
| tag | str | N | 板单类型（涨停/炸板/跌停/自然涨停/竞价，默认为涨停) |
| start_date | str | N | 开始日期 |
| end_date | str | N | 结束日期 |

输出参数

| 名称 | 类型 | 默认显示 | 描述 |
| --- | --- | --- | --- |
| ts_code | str | Y | 代码 |
| name | str | Y | 名称 |
| trade_date | str | Y | 交易时间 |
| lu_time | str | Y | 涨停时间 |
| ld_time | str | Y | 跌停时间 |
| open_time | str | Y | 开板时间 |
| last_time | str | Y | 最后涨停时间 |
| lu_desc | str | Y | 涨停原因 |
| tag | str | Y | 标签 |
| theme | str | Y | 板块 |
| net_change | float | Y | 主力净额(元) |
| bid_amount | float | Y | 竞价成交额(元) |
| status | str | Y | 状态（N连板） |
| bid_change | float | Y | 竞价净额 |
| bid_turnover | float | Y | 竞价换手% |
| lu_bid_vol | float | Y | 涨停委买额 |
| pct_chg | float | Y | 涨跌幅% |
| bid_pct_chg | float | Y | 竞价涨幅% |
| rt_pct_chg | float | Y | 实时涨幅% |
| limit_order | float | Y | 封单 |
| amount | float | Y | 成交额 |
| turnover_rate | float | Y | 换手率% |
| free_float | float | Y | 实际流通 |
| lu_limit_order | float | Y | 最大封单 |

接口用法

```python
pro = ts.pro_api()

df = pro.kpl_list(trade_date='20240927', tag='涨停', fields='ts_code,name,trade_date,tag,theme,status')
```

数据样例

```python
ts_code  name      trade_date tag         theme         status
0    000762.SZ  西藏矿业   20240927  涨停       锂矿、盐湖提锂     首板
```